import { ISubnet, IVpc } from 'aws-cdk-lib/aws-ec2';
import { IRole } from 'aws-cdk-lib/aws-iam';
import { IBucket } from 'aws-cdk-lib/aws-s3';
/**
 * Properties for S3DataCopy construct
 */
export interface S3DataCopyProps {
    /**
       * The source bucket
       */
    readonly sourceBucket: IBucket;
    /**
       * The source bucket prefix with a slash at the end
       * @default - No prefix is used
       */
    readonly sourceBucketPrefix?: string;
    /**
       * The source bucket region
       */
    readonly sourceBucketRegion: string;
    /**
       * the target bucket
       */
    readonly targetBucket: IBucket;
    /**
       * the target bucket prefix with a slash at the end
       * @default - No prefix is used
       */
    readonly targetBucketPrefix?: string;
    /**
       * The IAM role to use in the custom resource for copying data.
       * @default - A new role is created
       */
    readonly executionRole?: IRole;
    /**
       * The VPC to deploy the custom resource in.
       * @default - The Custom Resource is executed in VPCs owned by AWS Lambda service.
       */
    readonly vpc?: IVpc;
    /**
       * The subnets to deploy the custom resource in.
       * @default - The Custom Resource is executed in VPCs owned by AWS Lambda service.
       */
    readonly subnets?: ISubnet[];
}
